summaryrefslogtreecommitdiffstats
path: root/src/autotraceformats.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/autotraceformats.h')
-rw-r--r--src/autotraceformats.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/autotraceformats.h b/src/autotraceformats.h
index aa00e9b..479e25b 100644
--- a/src/autotraceformats.h
+++ b/src/autotraceformats.h
@@ -35,10 +35,10 @@ Q_OBJECT
public:
//! Standard TQObject-like constructor
/** The constructor, nothing fancy
* \param tqparent The tqparent of the TQObject
* \param name The name of the TQObject
*/
- AutotraceFormats(TQObject *tqparent = 0, const char *name = 0);
+ AutotraceFormats(TQObject *parent = 0, const char *name = 0);
//!Returns the list of supported input formats
/** This class returns the list of formats returned by <code>autotrace -list-input-formats</code>
* \return The supported formats
@@ -35,10 +35,10 @@ Q_OBJECT
//! Standard TQObject-like constructor
/** The constructor, nothing fancy
- * \param tqparent The tqparent of the TQObject
+ * \param parent The parent of the TQObject
* \param name The name of the TQObject
*/